/*
 icq-servers.c : irssi

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "module.h"

#include "icq-commands.h"
#include "icq-servers.h"
#include "icq-protocol.h"

static void cmd_sendmsg(const char *data, ICQ_SERVER_REC * server)
{
	char *uin, *text = NULL;
	void *free_arg;

	CMD_ICQ_SERVER(server);

	if (!cmd_get_params(data, &free_arg, 2, &uin, &text))
		return;
	if (text && *text)
		icq_sendmsg(server, uin, text);
	else
		cmd_param_error(CMDERR_NOT_ENOUGH_PARAMS);
	cmd_params_free(free_arg);
}

static void cmd_addbuddy(const char *data, ICQ_SERVER_REC * server)
{
	char *uin, *nick = NULL;
	void *free_arg;

	CMD_ICQ_SERVER(server);

	if (!cmd_get_params(data, &free_arg, 2, &uin, &nick))
		return;

	if (nick && *nick)
		icq_addbuddy(server, uin, nick);
	else
		cmd_param_error(CMDERR_NOT_ENOUGH_PARAMS);
	cmd_params_free(free_arg);
}

static void cmd_away(const char *data, ICQ_SERVER_REC * server)
{
	CMD_ICQ_SERVER(server);

	icq_setstatus(server, data);
}

static void cmd_whois(const char *data, ICQ_SERVER_REC * server)
{
	CMD_ICQ_SERVER(server);

	icq_whois(server, data);
}

void icq_commands_init(void)
{
	command_bind_icq("sendmsg", NULL, (SIGNAL_FUNC) cmd_sendmsg);
	command_bind_icq("addbuddy", NULL, (SIGNAL_FUNC) cmd_addbuddy);
	command_bind_icq("away", NULL, (SIGNAL_FUNC) cmd_away);
	command_bind_icq("whois", NULL, (SIGNAL_FUNC) cmd_whois);

	command_set_options("connect", "+icqnet");
}

void icq_commands_deinit(void)
{
	command_unbind("sendmsg", (SIGNAL_FUNC) cmd_sendmsg);
	command_unbind("addbuddy", (SIGNAL_FUNC) cmd_addbuddy);
	command_unbind("away", (SIGNAL_FUNC) cmd_away);
	command_unbind("whois", (SIGNAL_FUNC) cmd_whois);
}
