/*
 fe-icq.c : irssi

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "module.h"
#include "module-formats.h"
#include "signals.h"
#include "commands.h"
#include "servers-setup.h"
#include "levels.h"

#include "icq.h"
#include "icq-servers.h"
#include "icq-protocol.h"

#include "printtext.h"
#include "themes.h"

static void sig_server_add_fill(SERVER_SETUP_REC *rec,
		GHashTable *optlist)
{
	char *value;

	value = g_hash_table_lookup(optlist, "icqnet");
	if (value != NULL) {
		g_free_and_null(rec->chatnet);
		if (*value != '\0') rec->chatnet = g_strdup(value);
	}
}

static void nick_modechange(ICQ_SERVER_REC *server, char *uin, char *mode)
{
	printformat(server, uin, MSGLEVEL_MODES, ICQTXT_MODECHANGE, uin, mode);
}

static void nick_unknown(ICQ_SERVER_REC *server, char *uin)
{
	printformat(server, uin, MSGLEVEL_MSGS, ICQTXT_NOSUCH);
}

void fe_icq_init(void)
{
	theme_register(fecommon_icq_formats);

	signal_add("nick mode change", (SIGNAL_FUNC) nick_modechange);
	signal_add("nick unknown", (SIGNAL_FUNC) nick_unknown);

	signal_add("server add fill", (SIGNAL_FUNC) sig_server_add_fill);
	command_set_options("server add", "-icqnet");

	module_register("icq", "fe");
}

void fe_icq_deinit(void)
{
	signal_remove("nick mode change", (SIGNAL_FUNC) nick_modechange);
	signal_remove("nick unknown", (SIGNAL_FUNC) nick_unknown);

	signal_remove("server add fill", (SIGNAL_FUNC) sig_server_add_fill);
}
